@@ -29,8 +29,8 @@ else:
 
 import builtins
 
-from ..exceptions import SharedError
-from .validation import DataValidator
+from appserver_sdk_python_ai.shared.core.validation import DataValidator
+from appserver_sdk_python_ai.shared.exceptions import SharedError
 
 logger = logging.getLogger(__name__)
 
